@@ -2,23 +2,23 @@
 
 ;;;;
 ;;;; Copyright (C) 2016 - 2017
-;;;; David Pirotte <david at altosw dot be>
+;;;; Free Software Foundation, Inc.
 
-;;;; This file is part of Guile-CV
+;;;; This file is part of GNU Guile-CV.
 
-;;;; Guile-CV is free software; you can redistribute it and/or modify it
-;;;; under the terms of the GNU Lesser General Public License as
+;;;; GNU Guile-CV is free software; you can redistribute it and/or
+;;;; modify it under the terms of the GNU General Public License as
 ;;;; published by the Free Software Foundation; either version 3 of the
 ;;;; License, or (at your option) any later version.
 
-;;;; Guile-CV is distributed in the hope that it will be useful, but
+;;;; GNU Guile-CV is distributed in the hope that it will be useful, but
 ;;;; WITHOUT ANY WARRANTY; without even the implied warranty of
 ;;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-;;;; Lesser General Public License for more details.
+;;;; General Public License for more details.
 
-;;;; You should have received a copy of the GNU Lesser General Public
-;;;; License along with Guile-CV.  If not, see
-;;;; <https://www.gnu.org/licenses/lgpl.html>.
+;;;; You should have received a copy of the GNU General Public License
+;;;; along with GNU Guile-CV.  If not, see
+;;;; <https://www.gnu.org/licenses/gpl.html>.
 ;;;;
 
 ;;; Commentary:
@@ -31,6 +31,7 @@
   #:use-module (system foreign)
   #:use-module (rnrs bytevectors)
   #:use-module (ice-9 match)
+  #:use-module (ice-9 receive)
   #:use-module (srfi srfi-1)
   #:use-module (srfi srfi-4)
   #:use-module (cv support goops)
@@ -42,6 +43,8 @@
   #:use-module (cv support modules)
   #:use-module (cv support f32vector)
   #:use-module (cv support libguile-cv)
+  #:use-module (cv support utils)
+  #:use-module (cv support latex)
   #:use-module (cv init)
   #:use-module (cv idata)
   #:use-module (cv impex)
@@ -49,8 +52,10 @@
   #:use-module (cv filters)
   #:use-module (cv morphology)
   #:use-module (cv segmentation)
-  #:use-module (cv properties)
+  #:use-module (cv features)
   #:use-module (cv adds)
+  #:use-module (cv compose)
+  #:use-module (cv histogram)
   #:use-module (cv utils)
 
   #:duplicates (merge-generics
@@ -65,6 +70,7 @@
 			      (system foreign)
 			      (rnrs bytevectors)
 			      (ice-9 match)
+                              (ice-9 receive)
 			      (srfi srfi-1)
 			      (srfi srfi-4)
 			      (cv support goops)
@@ -76,6 +82,8 @@
 			      (cv support modules)
 			      (cv support f32vector)
                               (cv support libguile-cv)
+                              (cv support utils)
+                              (cv support latex)
 			      (cv init)
 			      (cv idata)
 			      (cv impex)
@@ -83,6 +91,8 @@
 			      (cv filters)
 			      (cv morphology)
 			      (cv segmentation)
-                              (cv properties)
+                              (cv features)
 			      (cv adds)
+                              (cv compose)
+                              (cv histogram)
 			      (cv utils)))
