@@ -54,6 +54,7 @@
 	    im-threshold
 	    im-and
 	    im-or
+            im-xor
 	    im-complement
 	    im-min
 	    im-max
@@ -172,7 +173,7 @@ Target.B = ((1 - Source.A) * BGColor.B) + (Source.A * Source.B)
        (else
 	(error "Not an RGBA (nor an RGB neither a GRAY) image."))))))
 
-(define* (im-threshold image threshold #:key (bg 'dark) (prec 1.0e-4))
+(define* (im-threshold image threshold #:key (bg 'black) (prec 1.0e-4))
   (if (and (>= threshold 0.0)
 	   (<= threshold 255.0))
       (match (match image
@@ -188,8 +189,8 @@ Target.B = ((1 - Source.A) * BGColor.B) + (Source.A * Source.B)
 	   ((c)
 	    (let ((c-copy (im-make-channel width height))
 		  (op (case bg
-			((dark) float>=?)
-			((light) float<=?)
+			((black) float>=?)
+			((white) float<=?)
 			(else
 			 (error "Invalid background: " bg)))))
 	      (do ((i 0
@@ -324,7 +325,8 @@ Target.B = ((1 - Source.A) * BGColor.B) + (Source.A * Source.B)
      (match image
        ((width height n-chan _)
 	(if (and (apply = (cons width (im-collect rest 'width)))
-		 (apply = (cons height (im-collect rest 'height))))
+		 (apply = (cons height (im-collect rest 'height)))
+                 (apply = (cons n-chan (im-collect rest 'n-channel))))
 	    (let ((img-2 (im-copy image))
 		  (n-cell (* width height))
 		  (c-channels (im-collect (map im-rgb->gray rest) 'gray)))
@@ -349,7 +351,8 @@ Target.B = ((1 - Source.A) * BGColor.B) + (Source.A * Source.B)
      (match image
        ((width height n-chan _)
 	(if (and (apply = (cons width (im-collect rest 'width)))
-		 (apply = (cons height (im-collect rest 'height))))
+		 (apply = (cons height (im-collect rest 'height)))
+                 (apply = (cons n-chan (im-collect rest 'n-channel))))
 	    (let ((img-2 (im-copy image))
 		  (n-cell (* width height))
 		  (c-channels (im-collect (map im-rgb->gray rest) 'gray)))
@@ -369,6 +372,34 @@ Target.B = ((1 - Source.A) * BGColor.B) + (Source.A * Source.B)
     ((image) image)
     (() (error "Invalid argument: " images))))
 
+(define (im-xor . images)
+  (match images
+    ((image . rest)
+     (match image
+       ((width height n-chan _)
+	(if (and (apply = (cons width (im-collect rest 'width)))
+		 (apply = (cons height (im-collect rest 'height)))
+                 (apply = (cons n-chan (im-collect rest 'n-channel))))
+            (list width height n-chan
+                  (let ((map-proc (if (and (> n-chan 1)
+                                           (%use-par-map)) par-map map)))
+                    (map-proc (lambda (channels)
+                                (im-xor-channels channels width height))
+                        (apply zip (im-collect images 'channels)))))
+	    (error "Size mismatch.")))))
+    ((image) image)
+    (() (error "Invalid argument: " images))))
+
+(define (im-xor-channels channels width height)
+  (let ((to (im-make-channel width height))
+        (n-cell (* width height)))
+    (do ((i 0
+            (+ i 1)))
+        ((= i n-cell))
+      (f32vector-set! to i
+                      (f32vector-xor-at-offset channels i)))
+    to))
+
 (define (im-complement image)
   (match image
     ((width height n-chan idata)
@@ -381,24 +412,42 @@ Target.B = ((1 - Source.A) * BGColor.B) + (Source.A * Source.B)
 	      idata))))))
 
 (define (im-min image)
-    (match image
-      ((width height n-chan idata)
-       (let ((map-proc (if (and (> n-chan 1)
-                                (%use-par-map)) par-map map)))
-         (map-proc
-          (lambda (channel)
-            (f32vector-min channel))
-          idata)))))
+  (match image
+    ((width height n-chan idata)
+     (match idata
+       ((c)
+        (im-min-channel c width))
+       (else
+        (let ((map-proc (if (%use-par-map) par-map map)))
+          (map-proc (lambda (channel)
+                      (receive (val row col)
+                          (im-min-channel channel width)
+                        (list val row col)))
+              idata)))))))
+
+(define (im-min-channel channel width)
+  (receive (val pos)
+      (f32vector-min channel)
+    (values val (quotient pos width) (remainder pos width))))
 
 (define (im-max image)
-    (match image
-      ((width height n-chan idata)
-       (let ((map-proc (if (and (> n-chan 1)
-                                (%use-par-map)) par-map map)))
-         (map-proc
-          (lambda (channel)
-            (f32vector-max channel))
-          idata)))))
+  (match image
+    ((width height n-chan idata)
+     (match idata
+       ((c)
+        (im-max-channel c width))
+       (else
+        (let ((map-proc (if (%use-par-map) par-map map)))
+          (map-proc (lambda (channel)
+                      (receive (val row col)
+                          (im-max-channel channel width)
+                        (list val row col)))
+              idata)))))))
+
+(define (im-max-channel channel width)
+  (receive (val pos)
+      (f32vector-max channel)
+    (values val (quotient pos width) (remainder pos width))))
 
 (define (im-transpose image)
   (match image
@@ -456,7 +505,7 @@ Target.B = ((1 - Source.A) * BGColor.B) + (Source.A * Source.B)
                               255)))
     to))
 
-(define* (im-scrap image val #:key (pred <) (con 8) (bg 'dark))
+(define* (im-scrap image val #:key (pred <) (con 8) (bg 'black))
   ;; (im-binary? image) is rather expensive
   (match image
     ((width height n-chan idata)
