@@ -34,6 +34,7 @@
   #:use-module (cv init)
   #:use-module (cv support utils)
   #:use-module (cv support float)
+  #:use-module (cv support libguile-cv)
 
   #:export (f32vector-min
 	    f32vector-max
@@ -44,6 +45,7 @@
 	    f32vector-complement
 	    f32vector-and-at-offset
 	    f32vector-or-at-offset
+            f32vector-xor-at-offset
 	    f32vector-sum-at-offset
 	    f32vector-mean-at-offset
 	    f32vector=-at-offset?
@@ -57,36 +59,34 @@
 
 
 (define* (f32vector-min v #:key (prec 1.0e-4))
-  (let ((n-cell (f32vector-length v))
-        (pos -1))
+  (let ((n-cell (f32vector-length v)))
     (case n-cell
       ((0) (error "Empty vector: " v))
-      ((1) (f32vector-ref v 0))
       (else
-       (let ((mini (f32vector-ref v 0)))
-	 (do ((i 1
-		 (+ i 1)))
-	     ((= i n-cell) (values mini pos))
-	   (let ((val (f32vector-ref v i)))
-	     (when (float<? val mini prec)
-	       (set! mini val)
-               (set! pos i)))))))))
+       (do ((mini (f32vector-ref v 0))
+            (pos 0)
+            (i 1
+               (+ i 1)))
+           ((= i n-cell) (values mini pos))
+         (let ((val (f32vector-ref v i)))
+           (when (float<? val mini prec)
+             (set! mini val)
+             (set! pos i))))))))
 
 (define* (f32vector-max v #:key (prec 1.0e-4))
-  (let ((n-cell (f32vector-length v))
-        (pos -1))
+  (let ((n-cell (f32vector-length v)))
     (case n-cell
       ((0) (error "Empty vector: " v))
-      ((1) (f32vector-ref v 0))
       (else
-       (let ((maxi (f32vector-ref v 0)))
-	 (do ((i 1
-		 (+ i 1)))
-	     ((= i n-cell) (values maxi pos))
-	   (let ((val (f32vector-ref v i)))
-	     (when (float>? val maxi)
-	       (set! maxi val)
-               (set! pos i)))))))))
+       (do ((maxi (f32vector-ref v 0))
+            (pos 0)
+            (i 1
+               (+ i 1)))
+           ((= i n-cell) (values maxi pos))
+         (let ((val (f32vector-ref v i)))
+           (when (float>? val maxi)
+             (set! maxi val)
+             (set! pos i))))))))
 
 (define* (f32vector-reduce init op v #:key (n-cell #f))
   (let ((n-cell (or n-cell
@@ -160,6 +160,28 @@
 				 #:key (prec 1.0e-4))
   (float>? (f32vector-sum-at-offset vectors i) 0.0 prec))
 
+(define (pixel-logior-1 vals result)
+  (if (null? vals)
+      result
+      (let ((a result)
+            (b (car vals)))
+        (pixel-logior-1 (cdr vals)
+                        (logior (logand a (- 255 b))
+                                (logand (- 255 a) b))))))
+
+(define (pixel-logior vals)
+  (match vals
+    ((a) a)
+    ((a . rests)
+     (pixel-logior-1 rests a))
+    (else
+     (error "Invalid argument: vals"))))
+
+(define (f32vector-xor-at-offset vectors i)
+  (pixel-logior (map (lambda (vector)
+                       (float->int (f32vector-ref vector i)))
+                  vectors)))
+
 (define (f32vector-sum-at-offset vectors i)
   (reduce +
 	  0.0
