@@ -68,24 +68,32 @@
 	      (iota n-cell))))))
     image))
 
-(define (make-test-image-gray type)
-    (let* ((img (im-make 3 3 1))
+(define (make-test-image-gray-type type)
+  (let* ((img (im-make 3 3 1))
 	 (chan (im-channel img 0)))
     (case type
+      ((empty)
+       img)
       ((center)
        (f32vector-set! chan 4 255.0))
       ((corner)
        (for-each (lambda (i)
 		   (f32vector-set! chan i 255.0))
 	   '(0 2 6 8)))
-      ((los losange)
+      ((diamond)
        (for-each (lambda (i)
 		   (f32vector-set! chan i 255.0))
 	   '(1 3 5 7)))
-      ((squa square)
+      ((square)
        (for-each (lambda (i)
 		   (f32vector-set! chan i 255.0))
-	   '(0 1 2 3 5 6 7 8))))
+	   '(0 1 2 3 5 6 7 8)))
+      ((full)
+       (for-each (lambda (i)
+		   (f32vector-set! chan i 255.0))
+	   '(0 1 2 3 4 5 6 7 8)))
+      (else
+       (error "No such image gray type:" type)))
     img))
 
 (define (make-test-image-logical type)
@@ -98,11 +106,11 @@
        (for-each (lambda (i)
 		   (f32vector-set! chan i (exact->inexact i)))
 	   '(0 2 6 8)))
-      ((los losange)
+      ((diamond)
        (for-each (lambda (i)
 		   (f32vector-set! chan i (exact->inexact i)))
 	   '(1 3 5 7)))
-      ((squa square)
+      ((square)
        (for-each (lambda (i)
 		   (f32vector-set! chan i (exact->inexact i)))
 	   '(0 1 2 3 5 6 7 8))))
@@ -168,23 +176,23 @@
 
 
 (define-method (test-idata-3 (self <guile-cv-tests-cv>))
-  (let* ((empty (make-test-image-gray 'empty))
-	 (center (make-test-image-gray 'center))
-	 (square (make-test-image-gray 'square))
-	 (diamond (make-test-image-gray 'losange))
+  (let* ((empty (make-test-image-gray-type 'empty))
+	 (center (make-test-image-gray-type 'center))
+	 (square (make-test-image-gray-type 'square))
+	 (diamond (make-test-image-gray-type 'diamond))
 	 (img-1 (make-test-image-rgb 3 2)))
-    (assert-equal #t (im-image? empty))
-    (assert-equal #t (im-image? center))
-    (assert-equal #t (im-image? square))
-    (assert-equal #t (im-image? diamond))
-    (assert-equal #t (im-gray? empty))
-    (assert-equal #f (im-rgb? empty))
-    (assert-equal #t (im-rgb? img-1))
-    (assert-equal #f (im-gray? img-1))
+    (assert-true (im-image? empty))
+    (assert-true (im-image? center))
+    (assert-true (im-image? square))
+    (assert-true (im-image? diamond))
+    (assert-true (im-gray? empty))
+    (assert-false (im-rgb? empty))
+    (assert-true (im-rgb? img-1))
+    (assert-false (im-gray? img-1))
     (im-fast-set! empty 0 0 -1.0)
-    (assert-equal #f (im-image? empty))
+    (assert-false (im-image? empty))
     (im-fast-set! empty 0 0 256.0)
-    (assert-equal #f (im-image? empty))))
+    (assert-false (im-image? empty))))
 
 
 (define-method (test-impex (self <guile-cv-tests-cv>))
@@ -193,24 +201,80 @@
 	 (b-file (string-append i-dir "/pp-17-label.png"))
 	 (l-file (string-append i-dir "/pp-17-bf.png")))
     (assert-equal '(85 95 1) (im-size b-file))
-    (assert-true ((@@ (cv impex) vigra-load-gray-image) b-file))
+    (assert ((@@ (cv impex) vigra-load-gray-image) b-file 85 95))
     (assert-equal '(85 95 3) (im-size l-file))
-    (assert-true ((@@ (cv impex) vigra-load-rgb-image) l-file))
+    (assert ((@@ (cv impex) vigra-load-rgb-image) l-file 85 95))
     (let ((bw (im-load b-file))
 	  (bf (im-load l-file)))
       (assert-equal '(85 95 1) (im-size bw))
-      (assert-true ((@@ (cv impex) vigra-save-gray-image) bw t-file))
+      (assert ((@@ (cv impex) vigra-save-gray-image) bw t-file 85 95))
       (assert-equal '(85 95 3) (im-size bf))
-      (assert-true ((@@ (cv impex) vigra-save-rgb-image) bf t-file)))))
+      (assert ((@@ (cv impex) vigra-save-rgb-image) bf t-file 85 95)))))
+
+
+(define-method (test-im-min/max (self <guile-cv-tests-cv>))
+  (let* ((gray (make-test-image-gray 3 2))
+         (rgb (make-test-image-rgb 3 2)))
+    (receive (val row col)
+        (im-min gray)
+      (assert-numeric-= val 0.0 1.0e-4)
+      (assert-numeric-= row 0 1.0e-4)
+      (assert-numeric-= col 0 1.0e-4))
+    (receive (val row col)
+        (im-max gray)
+      (assert-numeric-= val 5.0 1.0e-4)
+      (assert-numeric-= row 1 1.0e-4)
+      (assert-numeric-= col 2 1.0e-4))
+    (let ((rgb-mins (im-min rgb))
+          (expected-mins '((0.0 0 0) (6.0 0 0) (12.0 0 0)))
+          (rgb-maxs (im-max rgb))
+          (expected-maxs '((5.0 1 2) (11.0 1 2) (17.0 1 2))))
+      (for-each (lambda (item)
+                  (match item
+                    ((a b)
+                     (for-each (lambda (vals)
+                                 (match vals
+                                   ((need got)
+                                    (assert-numeric-= need got 1.0e-4))))
+                       (zip a b)))))
+          (zip rgb-mins expected-mins))
+      (for-each (lambda (item)
+                  (match item
+                    ((a b)
+                     (for-each (lambda (vals)
+                                 (match vals
+                                   ((need got)
+                                    (assert-numeric-= need got 1.0e-4))))
+                       (zip a b)))))
+          (zip rgb-maxs expected-maxs)))))
 
 
 (define-method (test-im-and (self <guile-cv-tests-cv>))
-  (let* ((empty (make-test-image-gray 'empty))
-	 (center (make-test-image-gray 'center))
-	 (square (make-test-image-gray 'square))
-	 (diamond (make-test-image-gray 'losange)))
-    (assert-equal diamond (im-and square diamond))
-    (assert-equal empty (im-and diamond center))))
+  (let* ((empty (make-test-image-gray-type 'empty))
+	 (center (make-test-image-gray-type 'center))
+	 (square (make-test-image-gray-type 'square))
+	 (diamond (make-test-image-gray-type 'diamond)))
+    (assert-true (im-=? diamond (im-and square diamond)))
+    (assert-true (im-=? empty (im-and diamond center)))))
+
+(define-method (test-im-or (self <guile-cv-tests-cv>))
+  (let* ((empty (make-test-image-gray-type 'empty))
+	 (center (make-test-image-gray-type 'center))
+         (corner (make-test-image-gray-type 'corner))
+	 (square (make-test-image-gray-type 'square))
+	 (diamond (make-test-image-gray-type 'diamond))
+         (full  (make-test-image-gray-type 'full)))
+    (assert-true (im-=? square (im-or corner square)))
+    (assert-true (im-=? full (im-or center square)))))
+
+(define-method (test-im-xor (self <guile-cv-tests-cv>))
+  (let* ((empty (make-test-image-gray-type 'empty))
+	 (center (make-test-image-gray-type 'center))
+         (corner (make-test-image-gray-type 'corner))
+	 (square (make-test-image-gray-type 'square))
+	 (diamond (make-test-image-gray-type 'diamond)))
+    (assert-true (im-=? diamond (im-xor corner square)))
+    (assert-true (im-=? corner (im-xor corner square square)))))
 
 
 (define (make-add-1-a)
