@@ -60,8 +60,14 @@
 	(pred1 (lambda (val) (float=? val 0.0)))
 	(pred2 (lambda (val) (float=? val 255.0)))
 	(pred3 (lambda (val) (float=? val 256.0))))
-    (assert-numeric-= -10.0 (f32vector-min v1) 1.0e-4)
-    (assert-numeric-= 255.0 (f32vector-max v1) 1.0e-4)
+    (receive (val pos)
+        (f32vector-min v1)
+      (assert-numeric-= val -10.0 1.0e-4)
+      (assert-numeric-= pos 1 1.0e-4))
+    (receive (val pos)
+        (f32vector-max v1)
+      (assert-numeric-= val 255.0 1.0e-4)
+      (assert-numeric-= pos 3 1.0e-4))
     (assert-true (f32vector=? v1 (f32vector-copy v1)))
     (assert-true (f32vector=? v3 (f32vector-complement v2)))
     (assert-false (f32vector-and-at-offset (list v2 v3) 0))
